==> ejc-cost-api-3.0.0-20201216.033737-15-sources.jar: com/ejianc/business/cost/vo/SettingVO.java <==
package com.ejianc.business.cost.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 成本设置
 * 
 * @author generator
 * 
 */
public class SettingVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.String taxFlag; // 是否含税 0-是，1-否
    private java.lang.Long projectId; // 项目
    private java.lang.String projectName; // 项目名称
    private java.lang.Long orgId; // 组织
    private java.lang.String orgName; // 组织名称
    private java.lang.String materialCost; // 物资成本 0-出库入成本，1-物资合同结算入成本
    private java.lang.String periodRule; // 期间规则 0-固定日期，1-自然月
    private java.lang.Integer endDay; // 月结束日期
    private java.lang.String memo; // 备注
    private java.lang.Integer billState; // 单据状态（审批必须字段）
    private java.lang.String createUserName; // 创建人名称

    // 科目明细子表
    private List<SubjectVO> subjectDetails = new ArrayList<SubjectVO>();

    public List<SubjectVO> getSubjectDetails() {
        return subjectDetails;
    }

    public void setSubjectDetails(List<SubjectVO> subjectDetails) {
        this.subjectDetails = subjectDetails;
    }

    /**
     * 是否含税 0-是，1-否
     */
    public java.lang.String getTaxFlag() {
        return taxFlag;
    }

    /**
     * 是否含税 0-是，1-否
     */
    public void setTaxFlag(java.lang.String taxFlag) {
        this.taxFlag = taxFlag;
    }
    /**
     * 项目
     */
    @ReferSerialTransfer(referCode="market-project")
    public Long getProjectId() {
        return projectId;
    }

    @ReferDeserialTransfer
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 组织
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 组织
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 物资成本 0-出库入成本，1-物资合同结算入成本
     */
    public java.lang.String getMaterialCost() {
        return materialCost;
    }

    /**
     * 物资成本 0-出库入成本，1-物资合同结算入成本
     */
    public void setMaterialCost(java.lang.String materialCost) {
        this.materialCost = materialCost;
    }
    /**
     * 期间规则 0-固定日期，1-自然月
     */
    public java.lang.String getPeriodRule() {
        return periodRule;
    }

    /**
     * 期间规则 0-固定日期，1-自然月
     */
    public void setPeriodRule(java.lang.String periodRule) {
        this.periodRule = periodRule;
    }
    /**
     * 月结束日期
     */
    public java.lang.Integer getEndDay() {
        return endDay;
    }

    /**
     * 月结束日期
     */
    public void setEndDay(java.lang.Integer endDay) {
        this.endDay = endDay;
    }
    /**
     * 备注
     */
    public java.lang.String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(java.lang.String memo) {
        this.memo = memo;
    }
    /**
     * 单据状态（审批必须字段）
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态（审批必须字段）
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 创建人名称
     */
    public java.lang.String getCreateUserName() {
        return createUserName;
    }

    /**
     * 创建人名称
     */
    public void setCreateUserName(java.lang.String createUserName) {
        this.createUserName = createUserName;
    }
    
}

==> ejc-cost-api-3.0.0-20221028.041657-200-sources.jar: com/ejianc/business/cost/vo/SettingVO.java <==
package com.ejianc.business.cost.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 成本设置
 * 
 * @author generator
 * 
 */
public class SettingVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.String taxFlag; // 是否含税 0-是，1-否
    private java.lang.Long projectId; // 项目
    private java.lang.String projectName; // 项目名称
    private java.lang.Long orgId; // 组织
    private java.lang.String orgName; // 组织名称
    private java.lang.String materialCost; // 物资成本 0-出库入成本，1-物资合同结算入成本
    private java.lang.String periodRule; // 期间规则 0-固定日期，1-自然月
    private java.lang.Integer endDay; // 月结束日期
    private java.lang.String memo; // 备注
    private java.lang.Integer billState; // 单据状态（审批必须字段）
    private java.lang.String createUserName; // 创建人名称
    private Integer pushFlag; // 是否推送 1是 0 否

    // 科目明细子表
    private List<SubjectVO> subjectDetails = new ArrayList<SubjectVO>();

    public List<SubjectVO> getSubjectDetails() {
        return subjectDetails;
    }

    public void setSubjectDetails(List<SubjectVO> subjectDetails) {
        this.subjectDetails = subjectDetails;
    }

    /**
     * 是否含税 0-是，1-否
     */
    public java.lang.String getTaxFlag() {
        return taxFlag;
    }

    /**
     * 是否含税 0-是，1-否
     */
    public void setTaxFlag(java.lang.String taxFlag) {
        this.taxFlag = taxFlag;
    }
    /**
     * 项目
     */
    @ReferSerialTransfer(referCode="market-project")
    public Long getProjectId() {
        return projectId;
    }

    @ReferDeserialTransfer
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 组织
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 组织
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 物资成本 0-出库入成本，1-物资合同结算入成本
     */
    public java.lang.String getMaterialCost() {
        return materialCost;
    }

    /**
     * 物资成本 0-出库入成本，1-物资合同结算入成本
     */
    public void setMaterialCost(java.lang.String materialCost) {
        this.materialCost = materialCost;
    }
    /**
     * 期间规则 0-固定日期，1-自然月
     */
    public java.lang.String getPeriodRule() {
        return periodRule;
    }

    /**
     * 期间规则 0-固定日期，1-自然月
     */
    public void setPeriodRule(java.lang.String periodRule) {
        this.periodRule = periodRule;
    }
    /**
     * 月结束日期
     */
    public java.lang.Integer getEndDay() {
        return endDay;
    }

    /**
     * 月结束日期
     */
    public void setEndDay(java.lang.Integer endDay) {
        this.endDay = endDay;
    }
    /**
     * 备注
     */
    public java.lang.String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(java.lang.String memo) {
        this.memo = memo;
    }
    /**
     * 单据状态（审批必须字段）
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态（审批必须字段）
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 创建人名称
     */
    public java.lang.String getCreateUserName() {
        return createUserName;
    }

    /**
     * 创建人名称
     */
    public void setCreateUserName(java.lang.String createUserName) {
        this.createUserName = createUserName;
    }

    public Integer getPushFlag() {
        return pushFlag;
    }

    public void setPushFlag(Integer pushFlag) {
        this.pushFlag = pushFlag;
    }
}
